@@ -339,9 +339,14 @@ def products_related_data(url_images, url_produits, each_picture, url_product, u
 
 
 def download_commit_db_images(url_images, url_produits):
+    print('======================================')
+    print(url_produits)
+    print('======================================')
+    print(url_images)
     if url_images:
         for image in url_images:
             try:
+                print(image)
                 download_or_remove(image.get('images', ''), "", image.get("product_id", ),
                                    image.get("product_url_mobile", ""), image.get("customer_name"),
                                    image.get('customer_type'), image.get('path'), image.get('project_name'))
@@ -436,7 +441,8 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
         else:
             db.add_or_update_products(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
                                       reference=urls, urlProduit=each_url_product, product_id=product_id,
-                                      product_url_mobile=product_url_mobile, hash_code=hash_files, project_name=project_name, update=data_product)
+                                      product_url_mobile=product_url_mobile, hash_code=hash_files,
+                                      project_name=project_name, update=data_product)
 
 
 def get_client_ip(request_client):
