@@ -12,7 +12,7 @@ import smtplib
 # Sending emails
 def send_payment_email(customer_email):
     first_name = db.get_profile(DATABASE_USERS_MANAGEMENT_TABLE_NAME, customer_email)[9]
-    logger.info("start sending email for informing_client_about_problem_shopify_payment  ...")
+    # logger.info("start sending email for informing_client_about_problem_shopify_payment  ...")
     server = smtplib.SMTP(SMTP_HOST, 587)
     server.login(SMTP_USERNAME, SMTP_PASSWORD)
     fromaddr = "FOQUS <hello@foqus.ai>"
@@ -65,7 +65,7 @@ def send_email_when_training_started(customer_name, project_name, api, subject):
         customer_email = custmer[3]
 
         try:
-            logger.info("start sending email of starting training ...")
+            # logger.info("start sending email of starting training ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
             fromaddr = "FOQUS <hello@foqus.ai>"
@@ -96,7 +96,7 @@ def send_email_to_admin(subject, message):
        '''
     try:
         if not LOCAL:
-            logger.info("start sending email ...")
+            # logger.info("start sending email ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
             fromaddr = "FOQUS <hello@foqus.ai>"
