@@ -82,14 +82,15 @@ class APIFoqus:
 
         return response
 
-    def apiget(self, post_fonction, customer_name, customer_type, project, url):
+    def apiget(self, post_fonction, customer_name, customer_type, project, url, bounding_box={}):
         if post_fonction == 'get_similars':
 
             response = requests.post(url=PREDICT_CALL_ADDRESS + "/similars/" + post_fonction,
                                         json={"customer_name": customer_name,
                                               "customer_type": customer_type,
                                               "project_name": project,
-                                              "url_image": url},
+                                              "url_image": url,
+                                              "bounding_box": bounding_box},
                                         headers=headers)
             return response.text
         elif post_fonction == 'get_category':
