@@ -41,7 +41,7 @@ class VPTree:
             return
 
         # Choose division boundary at median of distances.
-        distances = [self.dist_fn([float(pi) for pi in self.vp], [float(pi) for pi in points])]
+        distances = [self.dist_fn([float(pi) for pi in self.vp], [float(pi) for pi in p]) for p in points]
 
         median = np.median(distances)
 
